@@ -1,7 +1,7 @@
 #!/bin/sh -e
 
 VERSION=$2
-TAR=../bnd_$VERSION.orig.tar.gz
+TAR=../bnd_$VERSION.orig.tar.xz
 DIR=bnd-$VERSION
 GIT_DIR=bnd-git
 
@@ -15,7 +15,6 @@ git clone git://github.com/bndtools/bnd.git $GIT_DIR
 chmod +x debian/git-transform.sh
 debian/git-transform.sh $GIT_DIR $DIR
 
-tar -c -z -f $TAR $DIR
+XZ_OPT=--best tar -c -J -f $TAR $DIR
 rm -rf $DIR
 rm -rf $GIT_DIR
-
